@@ -181,7 +181,7 @@ enum Type {
     the constraints
     to be returned. These cautions are outlined where they occur.
 
-    @todo We really need a better way to get values out of these types, esp
+    @todo We really need a better way to get values out of these types, esp.
     the Float32, Int16, ..., types. In \e most cases we know the type, so a
     type specific method (one that requires a downcast to use) is OK. For
     example, Byte might have a method <tt>dods_byte Byte::value()</tt>. Sure
@@ -234,10 +234,11 @@ public:
     BaseType &operator=(const BaseType &rhs);
 
     /** Clone this instance. Allocate a new instance and copy \c *this into
-    it. This method must perform a deep copy.
+	it. This method must perform a deep copy.
+
         @note This method should \e not copy data values, but must copy all
         other fields in the object.
-    @return A newly allocated copy of \c this. */
+	@return A newly allocated copy of \c this. */
     virtual BaseType *ptr_duplicate() = 0;
 
     string name() const;
@@ -276,38 +277,37 @@ public:
     // I put this comment here because the version in BaseType.cc does not
     // include the exact_match or s variables since they are not used. Doxygen
     // was gaging on the comment.
+
     /** Returns a pointer to the contained variable in a composite class. The
         composite classes are those made up of aggregated simple data types.
         Array, Grid, and Structure are composite types, while Int and Float are
         simple types. This function is only used by composite classes. The
         BaseType implementation always returns null.
 
-        Several of the subclasses provide alternate access
-        methods that make sense for that particular data type. For example, the
-        Array class defines a <tt>*var(int i)</tt> method that returns the ith
-        entry in the Array data, and the Structure provides a 
-        <tt>*var(Vars_iter)</tt> function using a pseudo-index to access the 
-        different members of the structure.
+        Several of the subclasses provide alternate access methods
+        that make sense for that particular data type. For example,
+        the Array class defines a <tt>*var(int i)</tt> method that
+        returns the ith entry in the Array data, and the Structure
+        provides a <tt>*var(Vars_iter)</tt> function using a
+        pseudo-index to access the different members of the structure.
 
         @brief Returns a pointer to a member of a constructor class.
         @param name The name of the class member.  Defaults to ""
-        @param exact_match
-        True if only interested in variables whose full names match
-        \e n exactly. If false, returns the first variable
-        whose name matches \e name. For example, if
-        \e name is \c x and \c point.x is a variable, then var("x",
-        false) would return a BaseType pointer to \c point.x. If
-        \e exact_match was <tt>true</tt> then \e name
-        would need to be \c "point.x" for var to return that
-        pointer. This feature simplifies constraint expressions for
-        datasets which have complex, nested, constructor variables.
-        Defaults to true.
-        @param s Record the path to \e name. Defaults to null, in which case it is
-        not used.
-        
-        @return A pointer to the member named in the \e n argument. If no name is
-        given, the function returns the first (only) variable.  For example, an
-        Array has only one variable, while a Structure can have many. */
+        @param exact_match True if only interested in variables whose
+        full names match \e n exactly. If false, returns the first
+        variable whose name matches \e name. For example, if \e name
+        is \c x and \c point.x is a variable, then var("x", false)
+        would return a BaseType pointer to \c point.x. If \e
+        exact_match was <tt>true</tt> then \e name would need to be \c
+        "point.x" for var to return that pointer. This feature
+        simplifies constraint expressions for datasets which have
+        complex, nested, constructor variables. Defaults to true.
+        @param s Record the path to \e name. Defaults to null, in
+        which case it is not used.
+        @return A pointer to the member named in the \e n argument. If
+        no name is given, the function returns the first (only)
+        variable. For example, an Array has only one variable, while a
+        Structure can have many. */
     virtual BaseType *var(const string &name = "", bool exact_match = true,
                           btp_stack *s = 0);
     virtual BaseType *var(const string &name, btp_stack &s);
@@ -331,147 +331,143 @@ public:
     /** @name Abstract Methods */
     //@{
 
-    /** Return the number of bytes that are required to hold the instance's
-    value. In the case of simple types such as Int32, this is the size of
-    one Int32 (four bytes). For a String or Url type,
-    <tt>width()</tt> returns 
-    the number of bytes needed for a <tt>String *</tt> variable,
-    not the bytes 
-    needed for all the characters, since that value cannot be determined
-    from type information alone. For Structure, and other constructor
-    types size() returns the number of bytes needed to store pointers to
-    the C++ objects.
+    /** Return the number of bytes that are required to hold the
+	instance's value. In the case of simple types such as Int32,
+	this is the size of one Int32 (four bytes). For a String or
+	Url type, <tt>width()</tt> returns the number of bytes needed
+	for a <tt>String *</tt> variable, not the bytes needed for all
+	the characters, since that value cannot be determined from
+	type information alone. For Structure, and other constructor
+	types size() returns the number of bytes needed to store
+	pointers to the C++ objects.
 
-    @brief Returns the size of the class instance data. */
+	@brief Returns the size of the class instance data. */
     virtual unsigned int width() = 0;
 
     /** Reads the class data into the memory referenced by <i>val</i>.
-    The caller must allocate enough storage to <i>val</i> to hold the
-    class data.  If <i>val</i> is NULL, however, memory will be
-    allocated by this function with <tt>new()</tt>.  Even if the memory is
-    allocated this way, the caller is responsible for deallocating
-    that memory.  Array and List values for simple types are
-    stored as C would store an array.
+	The caller should either allocate enough storage to <i>val</i>
+	to hold the class data or set \c *val to null. If <i>*val</i>
+	is NULL, memory will be allocated by this function with
+	<tt>new()</tt>. If the memory is allocated this way, the
+	caller is responsible for deallocating that memory. Array and
+	values for simple types are stored as C would store an array.
 
-    @brief Reads the class data. 
+	@brief Reads the class data. 
 
-    @param val A pointer to a pointer to the memory into which the
-    class data will be copied.  If the value pointed to is NULL,
-    memory will be allocated to hold the data, and the pointer value
-    modified accordingly.  The calling program is responsible for
-    deallocating the memory indicated by this pointer.
+	@param val A pointer to a pointer to the memory into which the
+	class data will be copied. If the value pointed to is NULL,
+	memory will be allocated to hold the data, and the pointer
+	value modified accordingly. The calling program is responsible
+	for deallocating the memory references by this pointer.
 
-    @return The size (in bytes) of the information copied to <i>val</i>. 
+	@return The size (in bytes) of the information copied to <i>val</i>. 
     */
     virtual unsigned int buf2val(void **val) = 0;
 
-    /** Store the value pointed to by <i>val</i> in the object's internal
-    buffer. This function does not perform any checks, so users must
-    be sure that the thing pointed to can actually be stored in the
-    object's buffer.  For example, an array cannot easily be fit
-    into the data buffer for an Int32 object. 
+    /** Store the value pointed to by <i>val</i> in the object's
+	internal buffer. This function does not perform any checks, so
+	users must be sure that the thing pointed to can actually be
+	stored in the object's buffer.
+	
+	Only simple objects (Int, Float, Byte, and so on) and arrays
+	of these simple objects may be stored using this function. To
+	put data into more complex constructor types, use the
+	functions provided by that class.
 
-    Only simple objects (Int, Float, Byte, and so on) and arrays and
-    lists of these simple objects may be stored using this function.
-    To put data into more complex constructor functions, use the
-    functions provided by that class.  For example, use the <tt>var()</tt>
-    and <tt>add_var()</tt> members of the Grid class to manipulate data in
-    that class.
+	@brief Loads class data.
 
-    @brief Loads class data.
+	@param val A pointer to the data to be inserted into the class
+	data buffer.
 
-    @param val A pointer to the data to be inserted into the class
-    data buffer.
+	@param reuse A boolean value, indicating whether the class
+	internal data storage can be reused or not. If this argument
+	is TRUE, the class buffer is assumed to be large enough to
+	hold the incoming data, and it is <i>not</i> reallocated. If
+	FALSE, new storage is allocated. If the internal buffer has
+	not been allocated at all, this argument has no effect. This
+	is currently used only in the Vector class.
 
-    @param reuse A boolean value, indicating whether the class
-    internal data storage can be reused or not.  If this argument is
-    TRUE, the class buffer is assumed to be large enough to hold the
-    incoming data, and it is <i>not</i> reallocated.  If FALSE, new
-    storage is allocated.  If the internal buffer has not been
-    allocated at all, this argument has no effect.
-    This is currently used only in the Vector class.
-
-    @return The size (in bytes) of the information copied from <i>val</i>.
-    @see Grid
-    @see Vector::val2buf */
+	@return The size (in bytes) of the information copied from
+	<i>val</i>.
+	@see Grid
+	@see Vector::val2buf */
     virtual unsigned int val2buf(void *val, bool reuse = false) = 0;
 
     /** Sends the data from the indicated (local) dataset through the
-    connection identified by the <i>sink</i> parameter.  If the data
-    is not already incorporated into the DDS object, read the data
-    from the dataset. 
+	connection identified by the <i>sink</i> parameter. If the
+	data is not already incorporated into the DDS object, read the
+	data from the dataset.
 
-    This function is only used on the server side of the
-    client/server connection, and is generally only called from the
-    DDS::send() function.  It has no BaseType implementation; each
-    datatype child class supplies its own implementation.
+	This function is only used on the server side of the
+	client/server connection, and is generally only called from
+	the DODSFilter::send() function. It has no BaseType
+	implementation; each datatype child class supplies its own
+	implementation.
 
-    @brief Move data to the net.
-    @param dataset The (local) name of dataset to be read.
+	@brief Move data to the net.
+
+	@param dataset The (local) name of dataset to be read.
         @param eval Use this as the constraint expression evaluator.
-    @param dds The Data Descriptor Structure object corresponding to
-    this dataset.  See <i>The DODS User Manual</i> for information
-    about this structure.
-    @param sink A valid XDR pointer generally created with a call to
-    <tt>new_xdrstdio()</tt>. This typically routes data to a TCP/IP socket.
-    @param ce_eval A boolean value indicating whether to evaluate
-    the DODS constraint expression that may accompany this dataset.
-    The constraint expression is stored in <i>dds</i>.
-    @return This method always returns true. Older versions used the
-    return value to signal success or failure. 
-    @exception InternalErr.
-    @exception Error.
-    @see DDS */
+	@param dds The Data Descriptor Structure object corresponding
+	to this dataset. See <i>The DODS User Manual</i> for
+	information about this structure.
+	@param sink A valid XDR pointer generally created with a call
+	to <tt>new_xdrstdio()</tt>. This typically routes data to a
+	TCP/IP socket.
+	@param ce_eval A boolean value indicating whether to evaluate
+	the DODS constraint expression that may accompany this
+	dataset. The constraint expression is stored in <i>dds</i>.
+	@return This method always returns true. Older versions used
+	the return value to signal success or failure.
+
+	@exception InternalErr.
+	@exception Error.
+	@see DDS */
     virtual bool serialize(const string &dataset, ConstraintEvaluator &eval,
                            DDS &dds, XDR *sink, bool ce_eval = true) = 0;
 
     /** Receives data from the network connection identified by the
-    <tt>source</tt> parameter.  The data is put into the class data buffer
-    according to the input <tt>dds</tt>. 
+	<tt>source</tt> parameter. The data is put into the class data
+	buffer according to the input <tt>dds</tt>.
 
-    This function is only used on the client side of the
-    DODS client/server connection.
+	This function is only used on the client side of the DODS
+	client/server connection.
 
-    @brief Receive data from the net.
-    @param source A valid XDR pointer to the process connection to
-    the net.  This is generally created with a call to
-    <tt>new_xdrstdio()</tt>. 
-    @param dds The Data Descriptor Structure object corresponding to
-    this dataset.  See <i>The DODS User Manual</i> for information
-    about this structure.  This would have been received from the
-    server in an earlier transmission.
-    @param reuse A boolean value, indicating whether the class
-    internal data storage can be reused or not.  If this argument is
-    TRUE, the class buffer is assumed to be large enough to hold the
-    incoming data, and it is <i>not</i> reallocated.  If FALSE, new
-    storage is allocated.  If the internal buffer has not been
-    allocated at all, this argument has no effect.
-    @return Always returns TRUE.
-    @exception Error when a problem reading from the XDR stream is
-    found.
-    @see DDS 
-    */
+	@brief Receive data from the net.
+
+	@param source A valid XDR pointer to the process connection to
+	the net. This is generally created with a call to
+	<tt>new_xdrstdio()</tt>.
+	@param dds The Data Descriptor Structure object corresponding
+	to this dataset. See <i>The DODS User Manual</i> for
+	information about this structure. This would have been
+	received from the server in an earlier transmission.
+	@param reuse A boolean value, indicating whether the class
+	internal data storage can be reused or not. If this argument
+	is TRUE, the class buffer is assumed to be large enough to
+	hold the incoming data, and it is <i>not</i> reallocated. If
+	FALSE, new storage is allocated. If the internal buffer has
+	not been allocated at all, this argument has no effect.
+	@return Always returns TRUE.
+	@exception Error when a problem reading from the XDR stream is
+	found.
+	@see DDS */
     virtual bool deserialize(XDR *source, DDS *dds, bool reuse = false) = 0;
 
-    /** Prints the value of the variable, with its declaration.  This
-    function is primarily intended for debugging DODS applications.
-    However, it can be overloaded and used to do some useful things. Take a
-    look at the asciival and writeval clients, both of which overload this
-    to output the values of variables in different ways.
+    /** Prints the value of the variable, with its declaration. This
+	function is primarily intended for debugging DODS
+	applications. However, it can be overloaded and used to do
+	some useful things. Take a look at the asciival and writeval
+	clients, both of which overload this to output the values of
+	variables in different ways.
 
-    NB: This function uses C++'s iostream to handle creating the print
-    representations of simple type variables. For floating point numbers
-    this is set to six digits of precision by default. If you want more
-    precision (IEEE 64-bit floats have 15 digits of precision, 32-bit
-    floats have 8), use the setprecision() I/O manipulator. 
+	@brief Prints the value of the variable.
 
-    @brief Prints the value of the variable.
-    @param out The output FILE on which to print the value.
-    @param space This value is passed to the print_decl()
-    function, and controls the leading spaces of the output.
-    @param print_decl_p A boolean value controlling whether the
-    variable declaration is printed as well as the value.
-    */
+	@param out The output FILE on which to print the value.
+	@param space This value is passed to the print_decl()
+	function, and controls the leading spaces of the output.
+	@param print_decl_p A boolean value controlling whether the
+	variable declaration is printed as well as the value. */
     virtual void print_val(FILE *out, string space = "",
                            bool print_decl_p = true) = 0;
     //@}
