@@ -11,12 +11,12 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -31,11 +31,14 @@
 #endif
 
 /** Thrown when the DDX response cannot be parsed.. */
-class DDXParseFailed :public Error {
+class DDXParseFailed : public Error
+{
 public:
-    DDXParseFailed() : Error("The DDX response document parse failed.") {}
-    DDXParseFailed(const string &msg) : 
-	Error(string("The DDX response document parse failed: ") + msg) {}
+    DDXParseFailed() : Error("The DDX response document parse failed.")
+    {}
+    DDXParseFailed(const string &msg) :
+            Error(string("The DDX response document parse failed: ") + msg)
+    {}
 };
 
 #endif // ddx_exceptions_h
