@@ -27,7 +27,7 @@
 #include "config.h"
 
 static char rcsid[] not_used =
-    { "$Id: HTTPConnect.cc 16088 2007-03-28 21:42:19Z jimg $"
+    { "$Id: HTTPConnect.cc 16759 2007-06-26 19:37:30Z jimg $"
     };
 
 #include <stdio.h>
@@ -117,7 +117,7 @@ http_status_to_string(int status)
     else if (status >= SERVER_ERR_MIN && status <= SERVER_ERR_MAX)
         return string(http_server_errors[status - SERVER_ERR_MIN]);
     else
-        return string("Unknown Error: This indicates a problem with libdap++.\nPlease report this to support@unidata.ucar.edu.");
+        return string("Unknown Error: This indicates a problem with libdap++.\nPlease report this to support@opendap.org.");
 }
 
 /** Functor to parse the headers in the d_headers field. After the headers
@@ -226,10 +226,10 @@ save_raw_http_headers(void *ptr, size_t size, size_t nmemb, void *resp_hdrs)
 
     // Grab the header, minus the trailing newline. Or \r\n pair.
     string complete_line;
-    if (*(static_cast<char*>(ptr) + size *(nmemb - 2)) == '\r')
-        complete_line.assign(static_cast<char *>(ptr), size * nmemb - 2);
+    if (nmemb > 1 && *(static_cast<char*>(ptr) + size * (nmemb - 2)) == '\r')
+        complete_line.assign(static_cast<char *>(ptr), size * (nmemb - 2));
     else
-        complete_line.assign(static_cast<char *>(ptr), size * nmemb - 1);
+        complete_line.assign(static_cast<char *>(ptr), size * (nmemb - 1));
 
     // Store all non-empty headers that are not HTTP status codes
     if (complete_line != "" && complete_line.find("HTTP") == string::npos) {
