@@ -11,18 +11,18 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
- 
+
 // (c) COPYRIGHT URI/MIT 1999
 // Please read the full copyright statement in the file COPYRIGHT_URI.
 //
@@ -37,7 +37,7 @@
 #define _internalerr_h 1
 
 
-#include <stdio.h>		// For FILE *
+#include <stdio.h>  // For FILE *
 
 #include <string>
 
@@ -60,18 +60,19 @@
     @brief A class for software fault reporting.
     @author jhrg */
 
-class InternalErr: public Error {
+class InternalErr: public Error
+{
 
 public:
     /** These constructors always set the error code to <tt>internal_error</tt>.
-	
-	Note that there is no way to specify an error correction program for
-	an internal error.
 
-	@brief Constructors for the Error object
-	@name Constructors */
+    Note that there is no way to specify an error correction program for
+    an internal error.
+
+    @brief Constructors for the Error object
+    @name Constructors */
     //@{
-    /// 
+    ///
     InternalErr(const string &msg);
     ///
     InternalErr(const string &file, const int &line, const string &msg);
@@ -87,7 +88,7 @@ public:
 
     virtual ~InternalErr();
 
-  bool OK();
+    bool OK();
 };
 
 #endif // _internalerr_h
