@@ -11,25 +11,25 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
- 
+
 // (c) COPYRIGHT URI/MIT 1994-1999
 // Please read the full copyright statement in the file COPYRIGHT_URI.
 //
 // Authors:
 //      jhrg,jimg       James Gallagher <jgallagher@gso.uri.edu>
 
-// Interface for PassiveByte type. 
+// Interface for PassiveByte type.
 //
 // jhrg 9/7/94
 
@@ -46,7 +46,8 @@
     @brief Holds a single byte.
     @see BaseType
     */
-class PassiveByte: public Byte {
+class PassiveByte: public Byte
+{
 public:
     PassiveByte(const string &n = "");
 
@@ -58,9 +59,9 @@ public:
 
     virtual BaseType *ptr_duplicate();
 
-    virtual bool read( const string &dataset ) ;
+    virtual bool read(const string &dataset) ;
 
-    virtual bool set_value( dods_byte val ) ;
+    virtual bool set_value(dods_byte val) ;
 };
 
 #endif // _passivebyte_h
