@@ -11,18 +11,18 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
- 
+
 // (c) COPYRIGHT URI/MIT 1994-1999
 // Please read the full copyright statement in the file COPYRIGHT_URI.
 //
@@ -36,7 +36,9 @@
 
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: PassiveFloat64.cc 13266 2006-02-23 23:33:47Z jimg $"};
+static char rcsid[] not_used =
+    {"$Id: PassiveFloat64.cc 16088 2007-03-28 21:42:19Z jimg $"
+    };
 
 #include "PassiveFloat64.h"
 #include "debug.h"
@@ -47,20 +49,18 @@ using std::endl;
 
 /** The PassiveFloat64 constructor requires only the name of the variable
     to be created.  The name may be omitted, which will create a
-    nameless variable.  This may be adequate for some applications. 
-      
+    nameless variable.  This may be adequate for some applications.
+
     @param n A string containing the name of the variable to be
-    created. 
+    created.
 
 */
 PassiveFloat64::PassiveFloat64(const string &n) : Float64(n)
-{
-}
+{}
 
 PassiveFloat64::PassiveFloat64(const PassiveFloat64 &copy_from) : Float64(copy_from)
-{
-}
-    
+{}
+
 BaseType *
 PassiveFloat64::ptr_duplicate()
 {
@@ -76,7 +76,7 @@ PassiveFloat64 &
 PassiveFloat64::operator=(const PassiveFloat64 &rhs)
 {
     if (this == &rhs)
-	return *this;
+        return *this;
 
     dynamic_cast<BaseType &>(*this) = rhs;
 
@@ -86,20 +86,19 @@ PassiveFloat64::operator=(const PassiveFloat64 &rhs)
 }
 
 bool
-PassiveFloat64::read( const string & )
+PassiveFloat64::read(const string &)
 {
-    if( !read_p() )
-    {
-	val2buf( &_buf ) ;
-	set_read_p( true ) ;
+    if (!read_p()) {
+        val2buf(&_buf) ;
+        set_read_p(true) ;
     }
 
     return true ;
 }
 
 bool
-PassiveFloat64::set_value( dods_float64 val )
+PassiveFloat64::set_value(dods_float64 val)
 {
     _buf = val ;
-    return read( "" ) ;
+    return read("") ;
 }
