@@ -11,18 +11,18 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
- 
+
 // (c) COPYRIGHT URI/MIT 1994-1999
 // Please read the full copyright statement in the file COPYRIGHT_URI.
 //
@@ -45,7 +45,8 @@
     @see BaseType
     */
 
-class PassiveFloat64: public Float64 {
+class PassiveFloat64: public Float64
+{
 public:
     PassiveFloat64(const string &n = "");
 
@@ -57,9 +58,9 @@ public:
 
     virtual BaseType *ptr_duplicate();
 
-    virtual bool read( const string &dataset ) ;
+    virtual bool read(const string &dataset) ;
 
-    virtual bool set_value( dods_float64 val ) ;
+    virtual bool set_value(dods_float64 val) ;
 };
 
 #endif // _passivefloat64_h
