@@ -11,18 +11,18 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
- 
+
 // (c) COPYRIGHT URI/MIT 1994-1999
 // Please read the full copyright statement in the file COPYRIGHT_URI.
 //
@@ -36,7 +36,9 @@
 
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: PassiveStructure.cc 13269 2006-02-24 18:54:20Z jimg $"};
+static char rcsid[] not_used =
+    {"$Id: PassiveStructure.cc 16088 2007-03-28 21:42:19Z jimg $"
+    };
 
 #include <stdlib.h>
 
@@ -50,19 +52,17 @@ using std::endl;
 
 /** The PassiveStructure constructor requires only the name of the variable
     to be created.  The name may be omitted, which will create a
-    nameless variable.  This may be adequate for some applications. 
-      
+    nameless variable.  This may be adequate for some applications.
+
     @param n A string containing the name of the variable to be
-    created. 
+    created.
 */
 PassiveStructure::PassiveStructure(const string &n) : Structure(n)
-{
-}
+{}
 
 PassiveStructure::PassiveStructure(const PassiveStructure &copy_from) : Structure(copy_from)
-{
-}
-    
+{}
+
 BaseType *
 PassiveStructure::ptr_duplicate()
 {
@@ -78,7 +78,7 @@ PassiveStructure &
 PassiveStructure::operator=(const PassiveStructure &rhs)
 {
     if (this == &rhs)
-	return *this;
+        return *this;
 
     dynamic_cast<BaseType &>(*this) = rhs;
 
@@ -88,13 +88,12 @@ PassiveStructure::operator=(const PassiveStructure &rhs)
 }
 
 bool
-PassiveStructure::read( const string &dataset )
+PassiveStructure::read(const string &dataset)
 {
-    for( Vars_iter i = _vars.begin(); i != _vars.end(); i++ )
-    {
-	(*i)->read( dataset ) ;
+    for (Vars_iter i = _vars.begin(); i != _vars.end(); i++) {
+        (*i)->read(dataset) ;
     }
-    set_read_p( true ) ;
+    set_read_p(true) ;
 
     return true ;
 }
