@@ -11,12 +11,12 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -40,14 +40,15 @@ using namespace std;
     associated resources, this is overkill. However, some streams may require
     complex operations to free their resources once the client is done with
     the stream. Those classes should return a subclass of Response
-    which has those operations built into the destructor. 
-    
+    which has those operations built into the destructor.
+
     @todo If the code that parses the MIME headers was moved from Connect and
     HTTPConnect to this class and its children, it would be easier to build
     a FileConnect class (or maybe the specifics of the connection type could
-    be held in the Response object and HTTPConnect and the to be written 
+    be held in the Response object and HTTPConnect and the to be written
     FileConnect would not be needed). */
-class Response {
+class Response
+{
 private:
     /// The data stream
     FILE *d_stream;
@@ -63,45 +64,80 @@ private:
 protected:
     /** @name Suppressed default methods */
     //@{
-    Response() {}
-    Response(const Response &) {}
-    Response &operator=(const Response &) {
-	throw InternalErr(__FILE__, __LINE__, "Unimplemented assignment");
+    Response()
+    {}
+    Response(const Response &)
+    {}
+    Response &operator=(const Response &)
+    {
+        throw InternalErr(__FILE__, __LINE__, "Unimplemented assignment");
     }
     //@}
 
 public:
     /** Initialize with a stream. Create an instance initialized to a stream.
-	by default get_type() and get_version() return default values of
-	unknown_type and "dods/0.0", respectively. Specializations (see
-	HTTPResponse and HTTPConnect) may fill these fields in with other
-	values. */
-    Response(FILE *s) : d_stream(s), d_type(unknown_type), 
-			d_version("dods/0.0"), d_protocol("2.0"), 
-                        d_status(0) { }
+    by default get_type() and get_version() return default values of
+    unknown_type and "dods/0.0", respectively. Specializations (see
+    HTTPResponse and HTTPConnect) may fill these fields in with other
+    values. */
+    Response(FILE *s) : d_stream(s), d_type(unknown_type),
+            d_version("dods/0.0"), d_protocol("2.0"),
+            d_status(0)
+    { }
 
     /** Close the stream. */
-    virtual ~Response() { 
+    virtual ~Response()
+    {
         if (d_stream)
-	    fclose(d_stream); 
+            fclose(d_stream);
     }
 
     /** @name Accessors */
     //@{
-    virtual int get_status() const { return d_status; }
-    virtual FILE *get_stream() const { return d_stream; }
-    virtual ObjectType get_type() const { return d_type; }
-    virtual string get_version() const { return d_version; }
-    virtual string get_protocol() const { return d_protocol; }
+    virtual int get_status() const
+    {
+        return d_status;
+    }
+    virtual FILE *get_stream() const
+    {
+        return d_stream;
+    }
+    virtual ObjectType get_type() const
+    {
+        return d_type;
+    }
+    virtual string get_version() const
+    {
+        return d_version;
+    }
+    virtual string get_protocol() const
+    {
+        return d_protocol;
+    }
     //@}
 
     /** @name Mutators */
     //@{
-    virtual void set_status(int s) { d_status = s; }
-    virtual void set_stream(FILE *s) { d_stream = s; }
-    virtual void set_type(ObjectType o) { d_type = o; }
-    virtual void set_version(const string &v) { d_version = v; }
-    virtual void set_protocol(const string &p) { d_protocol = p; }
+    virtual void set_status(int s)
+    {
+        d_status = s;
+    }
+    virtual void set_stream(FILE *s)
+    {
+        d_stream = s;
+    }
+    virtual void set_type(ObjectType o)
+    {
+        d_type = o;
+    }
+    virtual void set_version(const string &v)
+    {
+        d_version = v;
+    }
+    virtual void set_protocol(const string &p)
+    {
+        d_protocol = p;
+    }
     //@}
 };
 
