@@ -11,22 +11,24 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
- 
+
 
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: ResponseTooBigErr.cc 13269 2006-02-24 18:54:20Z jimg $"};
+static char rcsid[] not_used =
+    {"$Id: ResponseTooBigErr.cc 16088 2007-03-28 21:42:19Z jimg $"
+    };
 
 #include <string>
 
@@ -34,13 +36,13 @@ static char rcsid[] not_used = {"$Id: ResponseTooBigErr.cc 13269 2006-02-24 18:5
 
 ResponseTooBigErr::ResponseTooBigErr() : Error()
 {
-    _error_code=unknown_error;
+    _error_code = unknown_error;
 }
 
 ResponseTooBigErr::ResponseTooBigErr(const string &msg) : Error()
 {
-    _error_code=unknown_error;
-    _error_message="";
-    _error_message+="A caching error was encounterd:\n";
-    _error_message+=msg+"\n";
+    _error_code = unknown_error;
+    _error_message = "";
+    _error_message += "A caching error was encounterd:\n";
+    _error_message += msg + "\n";
 }
