@@ -11,18 +11,18 @@
 // modify it under the terms of the GNU Lesser General Public
 // License as published by the Free Software Foundation; either
 // version 2.1 of the License, or (at your option) any later version.
-// 
+//
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 // Lesser General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public
 // License along with this library; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
 // You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
- 
+
 // (c) COPYRIGHT URI/MIT 1995-1999
 // Please read the full copyright statement in the file COPYRIGHT_URI.
 //
@@ -59,12 +59,12 @@
 bool do_version(const string &script_ver, const string &dataset_ver);
 
 bool do_data_transfer(bool compression, FILE *data_stream, DDS &dds,
-		      const string &dataset, const string &constraint);
+                      const string &dataset, const string &constraint);
 
-string find_ancillary_file(string pathname, string ext, string dir, 
-			   string file);
+string find_ancillary_file(const string &pathname, const string &ext,
+                           const string &dir, const string &file);
 
-string find_group_ancillary_file(string pathname, string ext);
+string find_group_ancillary_file(const string &pathname, const string &ext);
 
 void ErrMsgT(const string &Msgt);
 
@@ -72,7 +72,7 @@ string name_path(const string &path);
 
 string rfc822_date(const time_t t);
 
-time_t last_modified_time(string name);
+time_t last_modified_time(const string &name);
 //@}
 
 /** These functions are used to create the MIME headers for a message
@@ -86,18 +86,18 @@ time_t last_modified_time(string name);
     @see DODSFilter
 */
 //@{
-void set_mime_text(FILE *out, ObjectType type = unknown_type, 
-		   const string &version = "", EncodingType enc = x_plain,
-		   const time_t last_modified = 0);
-void set_mime_html(FILE *out, ObjectType type = unknown_type, 
-		   const string &version = "", EncodingType enc = x_plain,
-		   const time_t last_modified = 0);
-void set_mime_binary(FILE *out, ObjectType type = unknown_type, 
-		     const string &version = "", EncodingType enc = x_plain,
-		     const time_t last_modified = 0);
-void set_mime_error(FILE *out, int code = 404, 
-		    const string &reason = "Dataset not found",
-		    const string &version = "");
+void set_mime_text(FILE *out, ObjectType type = unknown_type,
+                   const string &version = "", EncodingType enc = x_plain,
+                   const time_t last_modified = 0);
+void set_mime_html(FILE *out, ObjectType type = unknown_type,
+                   const string &version = "", EncodingType enc = x_plain,
+                   const time_t last_modified = 0);
+void set_mime_binary(FILE *out, ObjectType type = unknown_type,
+                     const string &version = "", EncodingType enc = x_plain,
+                     const time_t last_modified = 0);
+void set_mime_error(FILE *out, int code = 404,
+                    const string &reason = "Dataset not found",
+                    const string &version = "");
 void set_mime_not_modified(FILE *out);
 
 //@}
