@@ -113,7 +113,7 @@
 
 #include "config.h"
 
-static char rcsid[] not_used = {"$Id: das.y 15975 2007-03-12 19:53:57Z jimg $"};
+static char rcsid[] not_used = {"$Id: das.tab.cc 16612 2007-06-04 22:08:57Z jimg $"};
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -138,7 +138,7 @@ using namespace std;
 
 // These macros are used to access the `arguments' passed to the parser. A
 // pointer to an error object and a pointer to an integer status variable are
-// passed in to the parser within a strucutre (which itself is passed as a
+// passed in to the parser within a structure (which itself is passed as a
 // pointer). Note that the ERROR macro explicitly casts OBJ to an ERROR *. 
 // The parser now throws an exception when it encounters an error. 5/23/2002
 // jhrg 
@@ -1648,7 +1648,7 @@ yyreduce:
 			    at = TOP_OF_STACK->append_container((yyvsp[(1) - (1)]));
 			}
 			catch (Error &e) {
-			    // rethrow with line number info
+			    // re-throw with line number info
 			    parse_error(e.get_error_message().c_str(), 
 					das_line_num);
 			}
@@ -1664,7 +1664,7 @@ yyreduce:
 #line 272 "das.y"
     {
 		    /* pop top of stack; store in attr_tab */
-		    DBG(cerr << " Poped attr_tab: " << TOP_OF_STACK << endl);
+		    DBG(cerr << " Popped attr_tab: " << TOP_OF_STACK << endl);
 		    POP;
 		;}
     break;
@@ -2083,7 +2083,7 @@ add_attribute(const string &type, const string &name, const string &value,
 	TOP_OF_STACK->append_attr(name, type, value);
     }
     catch (Error &e) {
-	// rethrow with line number
+	// re-throw with line number
 	parse_error(e.get_error_message().c_str(), das_line_num);
     }
 }
